@@ -36,11 +36,13 @@
 
 struct _GnomeDbErrorPrivate {
 	GList *current_list;
+	gint nerrors;
 	gint current_pos;
 
 	GtkWidget *error_number;
 	GtkWidget *error_description;
 
+	gint height; // Height of the dialog window when no details shown
 	GtkWidget *detail_button;
 	GtkWidget *detail_container;
 	GtkWidget *error_source;
@@ -91,19 +93,36 @@ display_current_error (GnomeDbError *error_widget)
 static void
 detail_button_clicked_cb (GtkButton *button, gpointer user_data)
 {
-	GtkLabel *label;
+	GtkButton *btn;
 	GnomeDbError *error_widget = (GnomeDbError *) user_data;
+	gint width;
+	gint height;
+	GtkWindow *window;
 
 	g_return_if_fail (GNOME_DB_IS_ERROR (error_widget));
 
-	label = GTK_LABEL (GTK_BIN (error_widget->priv->detail_container)->child);
+	window = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (error_widget)));
+	if (!GTK_WIDGET_TOPLEVEL (window))
+		window = NULL;
+
+	btn = GTK_BUTTON (error_widget->priv->detail_button);
 	if (GTK_WIDGET_VISIBLE (error_widget->priv->detail_container)) {
 		gtk_widget_hide (error_widget->priv->detail_container);
-		gtk_label_set_text (label, _("Show detail >>"));
-	}
-	else {
+		g_object_set (G_OBJECT (btn), "label", _("Show detail >>"), NULL);
+		if (window){
+			gtk_window_get_size (window, &width, &height);
+			gtk_window_resize (window,
+					   width,
+					   error_widget->priv->height);
+		}
+	} else {
 		gtk_widget_show (error_widget->priv->detail_container);
-		gtk_label_set_text (label, _("<< Hide detail"));
+		g_object_set (G_OBJECT (btn), "label", _("<< Hide detail"), NULL);
+		if (window){
+			gtk_window_get_size (window,
+					     &width,
+					     &error_widget->priv->height);
+		}
 	}
 }
 
@@ -253,6 +272,8 @@ gnome_db_error_clear (GnomeDbError *error_widget)
 
 	gda_error_list_free (error_widget->priv->current_list);
 	error_widget->priv->current_list = NULL;
+	error_widget->priv->nerrors = 0;
+	error_widget->priv->current_pos = 0;
 }
 
 /**
@@ -265,26 +286,15 @@ gnome_db_error_clear (GnomeDbError *error_widget)
 void
 gnome_db_error_show (GnomeDbError *error_widget, GList *errors)
 {
-	GList *l;
-	GList *new_list = NULL;
+	GList *new_list;
 
 	g_return_if_fail (GNOME_DB_IS_ERROR (error_widget));
 
 	gnome_db_error_clear (error_widget);
-	for (l = errors; l != NULL; l = g_list_next (l)) {
-		GdaError *error = gda_error_new ();
-		GdaError *tmp_error = GDA_ERROR (l->data);
-
-		gda_error_set_number (error, gda_error_get_number (tmp_error));
-		gda_error_set_description (error, gda_error_get_description (tmp_error));
-		gda_error_set_source (error, gda_error_get_source (tmp_error));
-		gda_error_set_sqlstate (error, gda_error_get_sqlstate (tmp_error));
-
-		new_list = g_list_append (new_list, error);
-	}
+	new_list = gda_error_list_copy (errors);
+	error_widget->priv->nerrors = g_list_length (new_list);
 
 	error_widget->priv->current_list = new_list;
-	error_widget->priv->current_pos = 0;
 	display_current_error (error_widget);
 }
 
@@ -316,9 +326,28 @@ gnome_db_error_next (GnomeDbError* error_widget)
 {
 	g_return_if_fail (GNOME_DB_IS_ERROR (error_widget));
 
-	if (error_widget->priv->current_pos <
-	    g_list_length (error_widget->priv->current_list) - 1) {
+	if (error_widget->priv->current_pos < error_widget->priv->nerrors - 1) {
 		error_widget->priv->current_pos++;
 		display_current_error (error_widget);
 	}
 }
+
+/**
+ * gnome_db_error_get_position
+ * @error_widget: the GnomeDbError widget.
+ *
+ * Get the position of the error being displayed.
+ *
+ * Returns: a non-negative integer on success.
+ */
+gint
+gnome_db_error_get_position (GnomeDbError *error_widget)
+{
+	g_return_val_if_fail (GNOME_DB_IS_ERROR (error_widget), -1);
+
+	if (!GTK_WIDGET_VISIBLE (GTK_WIDGET (error_widget)))
+		return -1;
+
+	return error_widget->priv->current_pos;
+}
+
