@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2001, The Free Software Foundation
+ * Copyright (C) 1999-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -22,6 +22,7 @@
 
 #include <gtk/gtklabel.h>
 #include <libgnomedb/gnome-db-gray-bar.h>
+#include <libgnomedb/gnome-db-util.h>
 
 #define PARENT_TYPE GTK_TYPE_EVENT_BOX
 
@@ -142,7 +143,7 @@ gnome_db_gray_bar_get_property (GObject *object,
 
 	switch (param_id) {
 	case PROP_TEXT :
-		g_value_set_string (value, gtk_label_get_text (bar->priv->label));
+		g_value_set_string (value, gtk_label_get_text (GTK_LABEL (bar->priv->label)));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
@@ -196,7 +197,7 @@ gnome_db_gray_bar_new (const gchar *label)
 	bar = g_object_new (GNOME_DB_TYPE_GRAY_BAR, NULL);
 	gnome_db_gray_bar_set_text (bar, label);
 
-	return bar;
+	return GTK_WIDGET (bar);
 }
 
 /**
