@@ -26,7 +26,7 @@
 #include <libgnomedb/gnome-db-login-dialog.h>
 #include <libgnomedb/gnome-db-stock.h>
 #include <libgnomeui/gnome-window-icon.h>
-#include "gnome-db-intl.h"
+#include <bonobo/bonobo-i18n.h>
 
 struct _GnomeDbLoginDialogPrivate {
 	GtkWidget *login;
@@ -194,7 +194,7 @@ gnome_db_login_dialog_new (const gchar *title)
 	dialog = g_object_new (GNOME_DB_TYPE_LOGIN_DIALOG, NULL);
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
 	gnome_window_icon_set_from_file (GTK_WINDOW (dialog),
-					 LIBGNOMEDB_PIXMAPSDIR "/gnome-db.png");
+					 LIBGNOMEDB_ICONSDIR "/gnome-db.png");
 
 	return GTK_WIDGET (dialog);
 }
