@@ -810,3 +810,28 @@ gnome_db_show_error (const gchar *format, ...)
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 }
+
+/**
+ * gnome_db_show_message
+ * @format: Format string.
+ *
+ * Displays an information message to the user.
+ */
+void
+gnome_db_show_message (const gchar *format, ...)
+{
+	va_list args;
+        gchar sz[2048];
+	GtkWidget *dialog;
+
+	/* build the message string */
+        va_start (args, format);
+        vsprintf (sz, format, args);
+        va_end (args);
+
+	/* create the error message dialog */
+	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO,
+					 GTK_BUTTONS_CLOSE, sz);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+}
